@@ -1,6 +1,6 @@
 #  gcompris - group_edit.py
 #
-# Copyright (C) 2005 Bruno Coudoin and Yves Combe
+# Copyright (C) 2005, 2008 Bruno Coudoin and Yves Combe
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -19,16 +19,12 @@
 
 import gtk
 import gobject
-import gcompris
 from gcompris import gcompris_gettext as _
 
 import group_user_list
 
 import constants
 
-# Database
-from pysqlite2 import dbapi2 as sqlite
-
 # User List Management
 (
   COLUMN_USERID,
@@ -226,9 +222,9 @@ class GroupEdit(gtk.Window):
 
     # class_id: only users in this class are inserted
     # group_id: only users in this group are inserted
-    # If with = True,  create a list only with user in the given class_id and group_id.
+    # If gwith = True,  create a list only with user in the given class_id and group_id.
     #           False, create a list only with user in the given class_id but NOT this group_id
-    def __create_model(self, _with, class_id, group_id):
+    def __create_model(self, gwith, class_id, group_id):
 
         model = gtk.ListStore(
             gobject.TYPE_INT,
@@ -247,9 +243,9 @@ class GroupEdit(gtk.Window):
                              (group_id, user[0]))
             user_is_already = self.cur.fetchall()
 
-            if(_with and user_is_already):
+            if(gwith and user_is_already):
                 self.add_user_in_model(model, user)
-            elif(not _with and not user_is_already):
+            elif(not gwith and not user_is_already):
                 self.add_user_in_model(model, user)
 
 
