@@ -1,6 +1,6 @@
 #  gcompris - module.py
 #
-# Copyright (C) 2005 Bruno Coudoin and Yves Combe
+# Copyright (C) 2005, 2008 Bruno Coudoin and Yves Combe
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -18,13 +18,13 @@
 
 # This is the base Class for all Administration modules.
 
-import gnomecanvas
+import goocanvas
 import gcompris
 import gcompris.utils
 import gcompris.skin
 import gtk
 import gtk.gdk
-from gettext import gettext as _
+from gcompris import gcompris_gettext as _
 
 class Module:
     """GCompris Administrative Module"""
@@ -45,10 +45,7 @@ class Module:
         return 999
 
     def init(self, index, select_area, callback):
-        print("Gcompris_administration init panel.")
-
-        height = 80
-        gap = 35
+        height = 90
         x   = select_area[0] + (select_area[2] - select_area[0]) / 2
         y1  = select_area[1] + height * index + 2
         y2  = select_area[1] + height * (index + 1) + 1
@@ -56,61 +53,65 @@ class Module:
         # Create our rootitem. We put each canvas item in it so at the end we
         # only have to kill it. The canvas deletes all the items it contains automaticaly.
 
-        self.root_select_item = self.canvas.add(
-            gnomecanvas.CanvasGroup,
-            x=0.0,
-            y=0.0
+        self.root_select_item = goocanvas.Group(
+            parent = self.canvas,
             )
 
-        self.select_item = self.root_select_item.add(
-            gnomecanvas.CanvasRect,
-            x1=select_area[0]+2,
-            y1=y1,
-            x2=select_area[2]-2,
-            y2=y2,
-            fill_color="white",
-            outline_color="white",
-            width_units=1.0
-            )
-        self.select_item.connect("event", callback, self)
-
-        y1 += 30
-        item = self.root_select_item.add(
-            gnomecanvas.CanvasPixbuf,
-            pixbuf = gcompris.utils.load_pixmap(gcompris.skin.image_to_skin("config_" +
-                                                                            self.module_name +
-                                                                            ".png")),
-            x = x,
+        self.select_item = goocanvas.Rect(
+            parent = self.root_select_item,
+            x = select_area[0]+2,
             y = y1,
-            anchor=gtk.ANCHOR_CENTER,
+            width = select_area[2] - select_area[0] - 4,
+            height = y2 - y1,
+            fill_color="white",
+            stroke_color="white",
+            line_width = 1.0
             )
-        item.connect("event", callback, self)
+        self.select_item.connect("button_press_event", callback, self)
 
-        y1 += gap
+        y1 += 5
 
-        item = self.root_select_item.add (
-            gnomecanvas.CanvasText,
+        itemimg = goocanvas.Svg(
+            parent = self.root_select_item,
+            svg_handle = gcompris.utils.load_svg("administration/config_" +
+                                                self.module_name +
+                                                 ".svgz")
+            )
+
+        bounds = itemimg.get_bounds()
+        centered_x = x - (bounds.x2 - bounds.x1)/2
+        itemimg.translate(centered_x, y1);
+        itemimg.connect("button_press_event", callback, self)
+        gcompris.utils.item_focus_init(itemimg, None)
+
+        y1 += bounds.y2 - bounds.y1 + 3
+
+        item = goocanvas.Text(
+            parent = self.root_select_item,
             text=_(self.module_label),
-            font=gcompris.skin.get_font("gcompris/tiny"),
-            x = x,
+            font = "Sans 8",
+            x = centered_x,
             y = y1,
             fill_color="black"
             )
-        item.connect("event", callback, self)
-
+        bounds = item.get_bounds()
+        centered_x = x - (bounds.x2 - bounds.x1)/2
+        item.props.x = centered_x
+        item.connect("button_press_event", callback, self)
+        gcompris.utils.item_focus_init(item, itemimg)
 
     def get_module_name(self):
         return self.module_name
 
     def start(self):
-        self.select_item.set(
+        self.select_item.set_properties(
             fill_color_rgba=self.selector_color,
-            outline_color_rgba=self.outline_color
+            stroke_color_rgba=self.outline_color
             )
 
     def stop(self):
-        self.select_item.set(
+        self.select_item.set_properties(
             fill_color="white",
-            outline_color="white"
+            stroke_color="white"
             )
 
