@@ -1,6 +1,6 @@
 #  gcompris - Tuxpaint Launcher
 #
-#  Copyright (C) 2004  Yves Combe
+#  Copyright (C) 2004, 2008  Yves Combe
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
 #   You should have received a copy of the GNU General Public License
 #   along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
-import gnomecanvas
+import goocanvas
 import gcompris
 import gcompris.utils
 import gcompris.bonus
@@ -33,13 +33,17 @@ import platform
 from gcompris import gcompris_gettext as _
 
 pid = None
+fles = None
 
 class Gcompris_tuxpaint:
   """TuxPaint Launcher"""
-  global pid
 
   def __init__(self, gcomprisBoard):
     self.gcomprisBoard = gcomprisBoard
+    self.rootitem = None
+    # global parameter to access object structures from global fonctions
+    global fles
+    fles=self
     pass
 
   def configuration(self, value, init):
@@ -72,9 +76,6 @@ class Gcompris_tuxpaint:
 
     self.window = self.gcomprisBoard.canvas.get_toplevel()
 
-    #global board
-    #board = self
-
     Prop = gcompris.get_properties()
 
     #get default values
@@ -83,27 +84,13 @@ class Gcompris_tuxpaint:
     #replace configured values
     self.config_dict.update(gcompris.get_board_conf())
 
-    self.rootitem = self.gcomprisBoard.canvas.root().add(
-      gnomecanvas.CanvasGroup,
-      x=0.0,
-      y=0.0
-      )
+    self.rootitem = goocanvas.Group(parent = self.gcomprisBoard.canvas.get_root_item())
 
     options = [progname]
 
     if (Prop.fullscreen and eval(self.config_dict['fullscreen'])):
       options.append('--fullscreen')
 
-    # tuxpaint size are 800x600 and 640x480 in 9.14
-    # in cvs (future 9.15) it will be
-    # [--640x480   | --800x600   | --1024x768 |
-    #  --1280x1024 | --1400x1050 | --1600x1200]
-    if (Prop.screensize and eval(self.config_dict['size'])):
-      if (Prop.screensize >=1):
-        options.append('--800x600')
-      else:
-        options.append('--640x480')
-
     if eval(self.config_dict['disable_shape_rotation']):
       options.append('--simpleshapes')
 
@@ -118,14 +105,7 @@ class Gcompris_tuxpaint:
 
     gcompris.sound.close()
 
-    # release pointergrab if running fullscreen, tuxpaint wants to grab the
-    # pointer itself
-    if (Prop.fullscreen and not Prop.noxf86vm):
-      gtk.gdk.pointer_ungrab()
-
-    #self.window.set_property("accept-focus", 0)
-    #self.window.set_keep_below(False)
-
+    global pid
     try:
        # bug in working_directory=None ?
        if (tuxpaint_dir):
@@ -140,9 +120,7 @@ class Gcompris_tuxpaint:
             flags=flags)
 
     except:
-       restore_grab(self)
-       gcompris.utils.dialog(_("Cannot find Tuxpaint.\nInstall it to use this activity !"),
-                             stop_board)
+       gcompris.utils.dialog(_("Cannot find Tuxpaint.\nInstall it to use this activity !"),stop_board)
        return
 
     gobject.child_watch_add(pid, child_callback, data=self, priority=gobject.PRIORITY_HIGH)
@@ -150,15 +128,15 @@ class Gcompris_tuxpaint:
     gcompris.bar_set(0)
     gcompris.bar_hide(1)
 
-    gcompris.set_background(self.rootitem,
-                            gcompris.skin.image_to_skin("gcompris-bg.jpg"))
+    gcompris.set_default_background(self.gcomprisBoard.canvas.get_root_item())
 
-    textItem = self.rootitem.add(
-      gnomecanvas.CanvasText,
+    textItem = goocanvas.Text(
+      parent = self.rootitem,
       text = _("Waiting for Tuxpaint to finish"),
       x = gcompris.BOARD_WIDTH/2,
       y = 185,
       fill_color_rgba = 0x000000ffL,
+      anchor = gtk.ANCHOR_CENTER,
       font = gcompris.skin.get_font("gcompris/board/title bold"),
       )
 
@@ -167,11 +145,11 @@ class Gcompris_tuxpaint:
     global pid
     # force kill - data loss
     if pid != None:
-      print "Tuxpaint not killed", self.pid
+      print "Tuxpaint not killed", pid
     #import os
     #os.kill(self.pid, signal.SIGKILL)
     if self.rootitem != None:
-      self.rootitem.destroy()
+      self.rootitem.remove()
       self.rootitem = None
 
   def set_level(self,level):
@@ -208,41 +186,36 @@ class Gcompris_tuxpaint:
                                                    self.apply_callback)
 
 
-    gcompris.boolean_box(bconfig, _('Inherit fullscreen setting from GCompris'), 'fullscreen',
-                         eval(self.config_dict['fullscreen']))
+    gcompris.boolean_box(bconfig, _('Inherit fullscreen setting from GCompris'), 'fullscreen', eval(self.config_dict['fullscreen']))
 
     gcompris.separator(bconfig)
 
-    gcompris.boolean_box(bconfig, _('Inherit size setting from GCompris (800x600, 640x480)'),
-                         'size', eval(self.config_dict['size']))
+    gcompris.boolean_box(bconfig, _('Inherit size setting from GCompris (800x600, 640x480)'), 'size', eval(self.config_dict['size']))
 
     gcompris.separator(bconfig)
 
-    gcompris.boolean_box(bconfig, _('Disable shape rotation'), 'disable_shape_rotation',
-                         eval(self.config_dict['disable_shape_rotation']))
+    gcompris.boolean_box(bconfig, _('Disable shape rotation'), 'disable_shape_rotation', eval(self.config_dict['disable_shape_rotation']))
 
     gcompris.separator(bconfig)
 
-    gcompris.boolean_box(bconfig, _('Show Uppercase text only'), 'uppercase_text',
-                         eval(self.config_dict['uppercase_text']))
+    gcompris.boolean_box(bconfig, _('Show Uppercase text only'), 'uppercase_text', eval(self.config_dict['uppercase_text']))
 
     gcompris.separator(bconfig)
 
-    stamps = gcompris.boolean_box(bconfig, _('Disable stamps'), 'disable_stamps',
-                                  eval(self.config_dict['disable_stamps']))
+    stamps = gcompris.boolean_box(bconfig, _('Disable stamps'), 'disable_stamps', eval(self.config_dict['disable_stamps']))
     stamps.connect("toggled", self.stamps_changed)
 
-    self.stamps_control = gcompris.boolean_box(bconfig, 'Disable stamps control',
-                                               'disable_stamps_control',
-                                               eval(self.config_dict['disable_stamps_control']))
+    self.stamps_control = gcompris.boolean_box(bconfig, 'Disable stamps control', 'disable_stamps_control', eval(self.config_dict['disable_stamps_control']))
     self.stamps_control.set_sensitive(not eval(self.config_dict['disable_stamps']))
 
   def stamps_changed(self, button):
     self.stamps_control.set_sensitive(not button.get_active())
 
   def apply_callback(self,table):
-    for key,value in table.iteritems():
-      gcompris.set_board_conf(self.configure_profile, self.gcomprisBoard, key, value)
+    if table:
+      for key,value in table.iteritems():
+        gcompris.set_board_conf(self.configure_profile, self.gcomprisBoard,
+                              key, value)
 
   def init_config(self):
     default_config_dict = { 'fullscreen'             : 'True',
@@ -254,26 +227,16 @@ class Gcompris_tuxpaint:
       }
     return default_config_dict
 
-def restore_grab(data):
-  # restore pointergrab if running fullscreen
-  if (gcompris.get_properties().fullscreen and
-      not gcompris.get_properties().noxf86vm):
-    gtk.gdk.pointer_grab(data.window.window, True, 0, data.window.window)
-
-    #bug in gtk2.6/window
-    if (gtk.gtk_version <= (2,6,10)):
-       data.window.unfullscreen()
-       data.window.fullscreen()
-
-
 def child_callback(fd,  cond, data):
-  restore_grab(data)
   global pid
   pid = None
-  gcompris.bar_hide(0)
-  gcompris.bonus.board_finished(gcompris.bonus.FINISHED_RANDOM)
+
+  global fles
+  fles.end()
+  gcompris.end_board()
 
 def stop_board():
-  gcompris.bar_hide(0)
-  gcompris.bonus.board_finished(gcompris.bonus.FINISHED_RANDOM)
+  global fles
+  fles.end()
+  gcompris.end_board()
 
